summaryrefslogtreecommitdiff
path: root/tools/binman/etype/section.py
diff options
context:
space:
mode:
authorSimon Glass <sjg@chromium.org>2022-03-06 06:18:59 +0300
committerSimon Glass <sjg@chromium.org>2022-03-19 04:24:25 +0300
commit80a66ae646eec82f4650bfc40f609584ba4bcebd (patch)
treec6c2208f853a54c13d7010aa3967d8331fd7218e /tools/binman/etype/section.py
parent6d427c4bcb601a0b271168f33737b53bda9b63d2 (diff)
downloadu-boot-80a66ae646eec82f4650bfc40f609584ba4bcebd.tar.xz
binman: Rename ExpandToLimit to extend_to_limit
The word 'expand' is used for entries which generate subentries. It is also used for entries that can have an '_expanded' version which is used to break out its contents. Rather than talking about expanding an entry's size, use the term 'extending'. It is slightly more precise and avoids the above conflicts. This change renders the old 'expand-size' property invalid, so add an error check for that. Signed-off-by: Simon Glass <sjg@chromium.org> Reviewed-by: Alper Nebi Yasak <alpernebiyasak@gmail.com>
Diffstat (limited to 'tools/binman/etype/section.py')
-rw-r--r--tools/binman/etype/section.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/tools/binman/etype/section.py b/tools/binman/etype/section.py
index 639b12d95b..8e8ee50bdf 100644
--- a/tools/binman/etype/section.py
+++ b/tools/binman/etype/section.py
@@ -386,7 +386,7 @@ class Entry_section(Entry):
self._PackEntries()
if self._sort:
self._SortEntries()
- self._ExpandEntries()
+ self._extend_entries()
data = self.BuildSectionData(True)
self.SetContents(data)
@@ -404,17 +404,17 @@ class Entry_section(Entry):
offset = entry.Pack(offset)
return offset
- def _ExpandEntries(self):
- """Expand any entries that are permitted to"""
+ def _extend_entries(self):
+ """Extend any entries that are permitted to"""
exp_entry = None
for entry in self._entries.values():
if exp_entry:
- exp_entry.ExpandToLimit(entry.offset)
+ exp_entry.extend_to_limit(entry.offset)
exp_entry = None
- if entry.expand_size:
+ if entry.extend_size:
exp_entry = entry
if exp_entry:
- exp_entry.ExpandToLimit(self.size)
+ exp_entry.extend_to_limit(self.size)
def _SortEntries(self):
"""Sort entries by offset"""